"""Resource modules for the Resletter SDK."""

from resletter.resources.campaigns import CampaignsResource
from resletter.resources.events import EventsResource
from resletter.resources.groups import GroupsResource
from resletter.resources.subscribers import SubscribersResource

__all__ = [
    "SubscribersResource",
    "GroupsResource",
    "CampaignsResource",
    "EventsResource",
]
